@@ -18,7 +18,7 @@
     Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
 
-  This must tie the EFI_DEVICE_PATH to /boot/efi/elilo.efi
+  This must tie the EFI_DEVICE_PATH to /boot/efi/EFI/redhat/grub.efi
   The  EFI_DEVICE_PATH will look something like:
     ACPI device path, length 12 bytes
     Hardware Device Path, PCI, length 6 bytes
@@ -239,6 +239,7 @@ warn_duplicate_name(list_t *boot_list)
 static var_entry_t *
 make_boot_var(list_t *boot_list)
 {
+	efi_status_t status;
 	var_entry_t *boot;
 	int free_number;
 	list_t *pos;
@@ -271,7 +272,12 @@ make_boot_var(list_t *boot_list)
 		free(boot);
 		return NULL;
 	}
-	create_variable(&boot->var_data);
+
+	status = create_variable(&boot->var_data);
+	if (status != EFI_SUCCESS) {
+		free(boot);
+		return NULL;
+	}
 	list_add_tail(&boot->list, boot_list);
 	return boot;
 }
@@ -328,6 +334,7 @@ add_to_boot_order(uint16_t num)
 	/* Now new_data has what we need */
 	memcpy(&(boot_order.Data), new_data, new_data_size);
 	boot_order.DataSize = new_data_size;
+	free(new_data);
 	return create_or_edit_variable(&boot_order);
 }
 
@@ -779,7 +786,7 @@ usage()
 	printf("\t-g | --gpt            force disk with invalid PMBR to be treated as GPT\n");
 	printf("\t-H | --acpi_hid XXXX  set the ACPI HID (used with -i)\n");
 	printf("\t-i | --iface name     create a netboot entry for the named interface\n");
-	printf("\t-l | --loader name     (defaults to \\elilo.efi)\n");
+	printf("\t-l | --loader name     (defaults to \\EFI\\redhat\\grub.efi)\n");
 	printf("\t-L | --label label     Boot manager display label (defaults to \"Linux\")\n");
 	printf("\t-n | --bootnext XXXX   set BootNext to XXXX (hex)\n");
 	printf("\t-N | --delete-bootnext delete BootNext\n");
@@ -807,7 +814,7 @@ set_default_opts()
 	opts.active          = -1;   /* Don't set it */
 	opts.timeout         = -1;   /* Don't set it */
 	opts.edd10_devicenum = 0x80;
-	opts.loader          = "\\elilo.efi";
+	opts.loader          = "\\EFI\\redhat\\grub.efi";
 	opts.label           = "Linux";
 	opts.disk            = "/dev/sda";
 	opts.iface           = NULL;
