@@ -35,7 +35,7 @@
 #define GPT_BLOCK_SIZE 512
 
 
-#define GPT_HEADER_SIGNATURE 0x5452415020494645
+#define GPT_HEADER_SIGNATURE ((uint64_t)(0x5452415020494645LL))
 #define GPT_HEADER_REVISION_V1_02 0x00010200
 #define GPT_HEADER_REVISION_V1_00 0x00010000
 #define GPT_HEADER_REVISION_V0_99 0x00009900
